@@ -228,8 +228,7 @@ class CRUDViews(UserPassesTestMixin, SingleTableView):
     def get_table_kwargs(self):
         kwargs = super().get_table_kwargs() or {}
         extra_columns = self.get_extra_table_columns()
-        if self.get_allow_edit():
-            extra_columns.append(('edit', self._get_edit_link_column()))
+        extra_columns.append(('edit', self._get_edit_link_column()))
         if self.get_allow_delete():
             extra_columns.append(('delete', self._get_delete_link_column()))
         kwargs.update(
@@ -241,19 +240,19 @@ class CRUDViews(UserPassesTestMixin, SingleTableView):
         return kwargs
 
     def _get_edit_link_column(self):
-        crud = self
+        # crud = self
+        #
+        # class EditLinkColumn(LinkColumn):
+        #     def render(self, value, record, bound_column):
+        #         if crud.allow_edit_for_record(record):
+        #             return super().render(value, record, bound_column)
+        #         return ''
 
-        class EditLinkColumn(LinkColumn):
-            def render(self, value, record, bound_column):
-                if crud.allow_edit_for_record(record):
-                    return super().render(value, record, bound_column)
-                return ''
-
-        return EditLinkColumn(viewname=self.get_edit_url_name(),
-                              text=mark_safe('<i class="fa fa-edit"></i>'),
-                              args=[A('pk')],
-                              verbose_name='',
-                              attrs={'a': {'class': 'btn btn-sm btn-primary'}})
+        return LinkColumn(viewname=self.get_edit_url_name(),
+                          text=mark_safe('<i class="fa fa-edit"></i>'),
+                          args=[A('pk')],
+                          verbose_name='',
+                          attrs={'a': {'class': 'btn btn-sm btn-primary'}})
 
     def _get_delete_link_column(self):
         crud = self
